==> MMDX-v1.41a-src.zip: MMDX-v1.41a-src/MikuMikuDanceXNADemo3/Game1.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
using MikuMikuDance.XNA;
using MikuMikuDance.XNA.Model;
using MikuMikuDance.XNA.Stages;

namespace MikuMikuDanceXNADemo3
{
    //JƃCg[V̍Đ
    /// <summary>
    /// MikuMikuDance for XNÃf
    /// ̃fł
    /// -Xe[W[V(J[VƃCg[V)̓ǂݍ
    /// -Xe[W[V̍Đ
    /// Ă܂
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        //MikuMikuDance for XNA
        MikuMikuDanceXNA mmd;
        //MMDff[^
        MMDModel model;
        //MMDXe[W[Vf[^
        MMDStageMotion motion1, motion2;

        public Game1()
        {
            //foCXMMDX̕Kv𖞂Ă邩`FbN
            graphics = new GraphicsDeviceManager(this);
            MikuMikuDanceXNA.CheckDevice(graphics, true);
            Content.RootDirectory = "Content";
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        /// <summary>
        /// LoadContent֐
        /// e탍[h͂Ń[hsĂƗǂ
        /// </summary>
        protected override void LoadContent()
        {
            //MikuMikuDanceXNA쐬
            mmd = new MikuMikuDanceXNA(this);
            //vWFNgContentɒǉĂMiku.pmdf[h
            //[hMikuMikuDanceXNA.LoadModel֐ōs
            //(ff[^͂ɂ܂肨؂肵܂B̃ft@CMITCZXKOł)
            model = mmd.LoadModel("Miku", this, Matrix.Identity);
            //ContentɒǉĂCamera.vmd, Light.vmd[V[h
            //Xe[Wp[Ṽ[hMikuMikuDanceXNA.LoadStageMotion֐ōs
            motion1 = mmd.LoadStageMotion("Camera");
            motion2 = mmd.LoadStageMotion("Light");
            //J̃vC[Ăяo
            //[V0ԃgbNɃZbg
            mmd.Camera.Player.SetMotion(0, motion1, true, mmd.Camera);
            //Cg̃vC[Ăяo
            //[V0ԃgbNɃZbg
            mmd.LightManager.Player.SetMotion(0, motion2, true, mmd.LightManager);
            
        }

        /// <summary>
        /// UnloadContent֐
        /// A[hKvȕ͂ŃA[hs
        /// </summary>
        protected override void UnloadContent()
        {
        }

        /// <summary>
        /// Abvf[g֐
        /// t[`ȊÕR[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Update(GameTime gameTime)
        {
            //XBoxRg[[Back{^I
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();
            //L[{[hEscL[I
            if (Keyboard.GetState().IsKeyDown(Keys.Escape))
                this.Exit();
            
            //ݍĐłȂ
            if (!mmd.Camera.Player.IsPlay(0))
            {
                //0ԃgbNɃZbgĂ郂[VĐ
                mmd.Camera.Player.Start(0, true);
                mmd.LightManager.Player.Start(0, true);
            }
            

            //fyъe[V̍ĐDrawableGameComponentpĂ邽
            //XNAɂ莩ŏs

            //XNAUpdates
            base.Update(gameTime);
        }

        /// <summary>
        /// Draw֐
        /// t[`R[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Draw(GameTime gameTime)
        {
            //ʂCornflowerBlueFŏ
            GraphicsDevice.Clear(Color.CornflowerBlue);

            //fDrawableGameComponentpĂ邽
            //XNAɂ莩ŕ`悳

            //XNADraws
            base.Draw(gameTime);
        }
    }
}

==> MMDX-v1.53a-src.zip: MMDX-v1.53a-src/MikuMikuDanceXNADemo3/Game1.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
using MikuMikuDance.XNA;
using MikuMikuDance.XNA.Model;
using MikuMikuDance.XNA.Stages;
using MikuMikuDance.XNA.Model.ModelData;

namespace MikuMikuDanceXNADemo3
{
    //JƃCg[V̍Đ
    /// <summary>
    /// MikuMikuDance for XNÃf
    /// ̃fł
    /// -Xe[W[V(J[VƃCg[V)̓ǂݍ
    /// -Xe[W[V̍Đ
    /// Ă܂
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        //MikuMikuDance for XNA
        MikuMikuDanceXNA mmd;
        //MMDff[^
        MMDModel model;
        //MMDXe[W[Vf[^
        MMDStageMotion motion1, motion2;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            //foCXMMDX̕Kv𖞂Ă邩`FbN
            MikuMikuDanceXNA.InitialSetup(this, graphics, true);
            Content.RootDirectory = "Content";
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        /// <summary>
        /// LoadContent֐
        /// e탍[h͂Ń[hsĂƗǂ
        /// </summary>
        protected override void LoadContent()
        {
            //MikuMikuDanceXNA쐬
            mmd = new MikuMikuDanceXNA(this);
            //vWFNgContentɒǉĂMiku.pmdf[h
            //[hMikuMikuDanceXNA.LoadModel֐ōs
            //(ff[^͂ɂ܂肨؂肵܂B̃ft@CMITCZXKOł)
            model = mmd.LoadModel("Miku", this, QuatTransform.Identity);
            //ContentɒǉĂCamera.vmd, Light.vmd[V[h
            //Xe[Wp[Ṽ[hMikuMikuDanceXNA.LoadStageMotion֐ōs
            motion1 = mmd.LoadStageMotion("Camera");
            motion2 = mmd.LoadStageMotion("Light");
            //J̃vC[Ăяo
            //[V0ԃgbNɃZbg
            mmd.Camera.Player.SetMotion(0, motion1, true, mmd.Camera);
            //Cg̃vC[Ăяo
            //[V0ԃgbNɃZbg
            mmd.LightManager.Player.SetMotion(0, motion2, true, mmd.LightManager);
            
        }

        /// <summary>
        /// UnloadContent֐
        /// A[hKvȕ͂ŃA[hs
        /// </summary>
        protected override void UnloadContent()
        {
        }

        /// <summary>
        /// Abvf[g֐
        /// t[`ȊÕR[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Update(GameTime gameTime)
        {
            //XBoxRg[[Back{^I
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();
            //L[{[hEscL[I
            if (Keyboard.GetState().IsKeyDown(Keys.Escape))
                this.Exit();
            
            //ݍĐłȂ
            if (!mmd.Camera.Player.IsPlay(0))
            {
                //0ԃgbNɃZbgĂ郂[VĐ
                mmd.Camera.Player.Start(0, true);
                mmd.LightManager.Player.Start(0, true);
            }
            

            //fyъe[V̍ĐDrawableGameComponentpĂ邽
            //XNAɂ莩ŏs

            //XNAUpdates
            base.Update(gameTime);
        }

        /// <summary>
        /// Draw֐
        /// t[`R[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Draw(GameTime gameTime)
        {
            //ʂCornflowerBlueFŏ
            GraphicsDevice.Clear(Color.CornflowerBlue);

            //fDrawableGameComponentpĂ邽
            //XNAɂ莩ŕ`悳

            //XNADraws
            base.Draw(gameTime);
        }
    }
}
